#define QT_FEATURE_alloca_h 1
#define QT_FEATURE_alloca 1
#define QT_FEATURE_alloca_malloc_h -1
#define QT_FEATURE_android_style_assets -1
#define QT_FEATURE_sse2 -1
#define QT_FEATURE_private_tests -1
#define QT_FEATURE_dbus 1
#define QT_FEATURE_dbus_linked 1
#define QT_FEATURE_gui 1
#define QT_FEATURE_libudev -1
#define QT_FEATURE_network 1
#define QT_FEATURE_posix_fallocate 1
#define QT_FEATURE_qml_debug 1
#define QT_FEATURE_reduce_exports -1
#define QT_FEATURE_reduce_relocations -1
#define QT_FEATURE_release_tools 1
#define QT_FEATURE_sql 1
#define QT_FEATURE_stack_protector_strong -1
#define QT_FEATURE_system_zlib 1
#define QT_FEATURE_testlib 1
#define QT_FEATURE_widgets 1
#define QT_FEATURE_xml 1
